==> mini_widget-0.1.8.tar.gz: lib/res/colors.dart <==
import 'package:flutter/material.dart';

class MiniColor {
  static const Color textDark = const Color(0xFF333333);
  static const Color textNormal = const Color(0xFF666666);
  static const Color textGray = const Color(0xFF999999);
  static const Color textGrayC = const Color(0xFFCCCCCC);
  static const Color divider = const Color(0xffe5e5e5);
  static const Color secondary = const Color(0xFF51DEC6);
  static const Color red = const Color(0xFFFF2B45);
  static const Color orange = const Color(0xFFF67264);
  static const Color white = Colors.white;
  static const Color paper = const Color(0xFFF5F5F5);
  static const Color lightGray = const Color(0xFFEEEEEE);
  static const Color gray = const Color(0xFF888888);
  static const Color blue = const Color(0xFF3688FF);
  static const Color golden = const Color(0xff8B7961);
  static const Color darkGray = const Color(0xFF333333);
  static const Color black = const Color(0xFF000000);
  static const Color black8a = const Color(0x8A000000);
  static const Color deepPink = const Color(0xffFF1493);
  static const Color background = const Color(0xffeaeceb);

  static const Color green = Colors.green;
  static const Color transparent = Colors.transparent;

  static const Color primary = Colors.blueAccent;
  static const Color buttonColor = Colors.green;
  static const Color buttonTextColor = const Color(0xFFFFFFFF);
  static const Color textSelectionColor = const Color(0xFF333333);

  /// 不处理、已删除、已退回等
  static const Color stateEnd = Colors.grey;

  /// 标签背景颜色
  static const Color tagBackColor = Color.fromARGB(25, 51, 51, 255);

  /// 报表-背景-浅蓝
  static const Color reportBackgroundColor1 = Color.fromARGB(255, 216, 223, 241);

  /// 报表-背景-浅蓝
  static const Color reportBackgroundColor2 = Color.fromARGB(255, 236, 241, 249);

  /// 报表-背景-纯色浅蓝
  static const Color reportBackgroundColor3 = Color.fromARGB(255, 236, 241, 249);

  /// 报表-不太重要的数据-浅红
  static const Color reportUnImportRed = Color.fromARGB(255, 250, 190, 175);

  /// 报表-不太重要的数据-浅绿
  static const Color reportUnImportGreen = Color.fromARGB(255, 170, 213, 155);

  /// 报表-重要的数据-青绿
  static const Color reportImportCyanBlue = Color.fromARGB(255, 0, 173, 79);

  /// 报表-重要的数据-绽蓝
  static const Color reportImportBluishBlue = Color.fromARGB(255, 6, 102, 177);

  /// 报表-重要的数据-枣红
  static const Color reportImportJujubeRed = Color.fromARGB(255, 237, 27, 58);

  static const List<Color> reportColorsOne = [
    // 红色
    Color(0xFF00994e),
    Color(0xFF00a8e1),
    Color(0xFF99cc00),
    Color(0xFFe30039),
    Color(0xFFfcd300),
    Color(0xFF800080),
    Color(0xFFff6600),
    Color(0xFF808000),
    Color(0xFFdb00c2),
    Color(0xFF008080),
    Color(0xFF0780cf),
    Color(0xFFc8cc00),
  ];

  /// 标签颜色
  static const Color tagColor = Color.fromARGB(255, 51, 153, 204);

  /// 强调色
  static const Color accentColor = const Color(0xFF3688FF);

  /// 提示颜色
  static const Color warnColor = const Color(0xffFF1493);
  static const Color errorColor = const Color(0xFFC5032B);
  static const Color scaffoldBackgroundColor = Colors.white;
  static const Color cardColor = Colors.white;

  static const Color gray_66 = const Color(0xFF666666); //102
}

==> mini_widget-1.0.0.tar.gz: lib/res/colors.dart <==
import 'package:flutter/material.dart';

class MiniColor {
  static const Color textDark = const Color(0xFF333333);
  static const Color textNormal = const Color(0xFF666666);
  static const Color textGray = const Color(0xFF999999);
  static const Color textGrayC = const Color(0xFFCCCCCC);
  static const Color divider = const Color(0xffe5e5e5);
  static const Color secondary = const Color(0xFF51DEC6);
  static const Color red = const Color(0xFFFF2B45);
  static const Color orange = const Color(0xFFF67264);
  static const Color white = Colors.white;
  static const Color paper = const Color(0xFFF5F5F5);
  static const Color lightGray = const Color(0xFFEEEEEE);
  static const Color gray = const Color(0xFF888888);
  static const Color blue = const Color(0xFF3688FF);
  static const Color golden = const Color(0xff8B7961);
  static const Color darkGray = const Color(0xFF333333);
  static const Color black = const Color(0xFF000000);
  static const Color black8a = const Color(0x8A000000);
  static const Color deepPink = const Color(0xffFF1493);
  static const Color background = const Color(0xffeaeceb);

  static const Color green = Colors.green;
  static const Color transparent = Colors.transparent;

  static const Color primary = Colors.blueAccent;
  static const Color buttonColor = Colors.green;
  static const Color buttonTextColor = const Color(0xFFFFFFFF);
  static const Color textSelectionColor = const Color(0xFF333333);

  /// 不处理、已删除、已退回等
  static const Color stateEnd = Colors.grey;

  /// 标签背景颜色
  static const Color tagBackColor = Color.fromARGB(25, 51, 51, 255);

  /// 报表-背景-浅蓝
  static const Color reportBackgroundColor1 =
      Color.fromARGB(255, 216, 223, 241);

  /// 报表-背景-浅蓝
  static const Color reportBackgroundColor2 =
      Color.fromARGB(255, 236, 241, 249);

  /// 报表-背景-纯色浅蓝
  static const Color reportBackgroundColor3 =
      Color.fromARGB(255, 236, 241, 249);

  /// 报表-不太重要的数据-浅红
  static const Color reportUnImportRed = Color.fromARGB(255, 250, 190, 175);

  /// 报表-不太重要的数据-浅绿
  static const Color reportUnImportGreen = Color.fromARGB(255, 170, 213, 155);

  /// 报表-重要的数据-青绿
  static const Color reportImportCyanBlue = Color.fromARGB(255, 0, 173, 79);

  /// 报表-重要的数据-绽蓝
  static const Color reportImportBluishBlue = Color.fromARGB(255, 6, 102, 177);

  /// 报表-重要的数据-枣红
  static const Color reportImportJujubeRed = Color.fromARGB(255, 237, 27, 58);

  static const List<Color> reportColorsOne = [
    // 红色
    Color(0xFF00994e),
    Color(0xFF00a8e1),
    Color(0xFF99cc00),
    Color(0xFFe30039),
    Color(0xFFfcd300),
    Color(0xFF800080),
    Color(0xFFff6600),
    Color(0xFF808000),
    Color(0xFFdb00c2),
    Color(0xFF008080),
    Color(0xFF0780cf),
    Color(0xFFc8cc00),
  ];

  /// 标签颜色
  static const Color tagColor = Color.fromARGB(255, 51, 153, 204);

  /// 强调色
  static const Color accentColor = const Color(0xFF3688FF);

  /// 提示颜色
  static const Color warnColor = const Color(0xffFF1493);
  static const Color errorColor = const Color(0xFFC5032B);
  static const Color scaffoldBackgroundColor = Colors.white;
  static const Color cardColor = Colors.white;

  static const Color gray_66 = const Color(0xFF666666); //102
}
